import os, sys

os.chdir("..")
sys.path.append(".")

sys.argv.append("-netpyne")

import Example4
